==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/TransactionStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TransactionStateDescription } from "./TransactionStateDescription";
/**
 * @hidden
 */
var TransactionStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TransactionStateDescriptionMetadata, _super);
    function TransactionStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TransactionStateDescriptionMetadata.b = function (a) {
        if (TransactionStateDescriptionMetadata.a == null) {
            TransactionStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TransactionStateDescriptionMetadata.c(TransactionStateDescriptionMetadata.a);
        }
        if (a.g(TransactionStateDescriptionMetadata.a)) {
            return;
        }
        a.s(TransactionStateDescriptionMetadata.a);
    };
    TransactionStateDescriptionMetadata.c = function (a) {
        a.item("IdRef", "(w:ID,xam:ID,wf:ID)DataRef");
        a.item("TransactionType", "ExportedType:string:TransactionType");
        a.item("TransactionType@names", "Add;Update;Delete");
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        a.item("VersionRef", "(w:Version,wf:Version)DataRef");
    };
    TransactionStateDescriptionMetadata.d = function (a) {
        TransactionStateDescriptionMetadata.b(a);
        a.u("TransactionState", function () { return new TransactionStateDescription(); });
        a.t("TransactionState", TransactionStateDescriptionMetadata.a);
    };
    TransactionStateDescriptionMetadata.$t = markType(TransactionStateDescriptionMetadata, 'TransactionStateDescriptionMetadata');
    TransactionStateDescriptionMetadata.a = null;
    return TransactionStateDescriptionMetadata;
}(Base));
export { TransactionStateDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/TransactionStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TransactionStateDescription } from "./TransactionStateDescription";
/**
 * @hidden
 */
var TransactionStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TransactionStateDescriptionMetadata, _super);
    function TransactionStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TransactionStateDescriptionMetadata.b = function (a) {
        if (TransactionStateDescriptionMetadata.a == null) {
            TransactionStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TransactionStateDescriptionMetadata.c(TransactionStateDescriptionMetadata.a);
        }
        if (a.j(TransactionStateDescriptionMetadata.a)) {
            return;
        }
        a.y(TransactionStateDescriptionMetadata.a);
    };
    TransactionStateDescriptionMetadata.c = function (a) {
        a.item("IdRef", "(w:ID,xam:ID,wf:ID)DataRef");
        a.item("TransactionType", "ExportedType:string:TransactionType");
        a.item("TransactionType@names", "Add;Update;Delete");
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        a.item("VersionRef", "(w:Version,wf:Version)DataRef");
    };
    TransactionStateDescriptionMetadata.d = function (a) {
        TransactionStateDescriptionMetadata.b(a);
        a.aa("TransactionState", function () { return new TransactionStateDescription(); });
        a.z("TransactionState", TransactionStateDescriptionMetadata.a);
    };
    TransactionStateDescriptionMetadata.$t = markType(TransactionStateDescriptionMetadata, 'TransactionStateDescriptionMetadata');
    TransactionStateDescriptionMetadata.a = null;
    return TransactionStateDescriptionMetadata;
}(Base));
export { TransactionStateDescriptionMetadata };
